@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11720 2019-09-23 06:12:17Z Lavender $
+# $Id: models.py 12420 2020-07-23 08:06:48Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,11 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-09-23 14:12:17 +0800 (Mon, 23 Sep 2019) $
-# $Revision: 11720 $
+# $Date: 2020-07-23 16:06:48 +0800 (Thu, 23 Jul 2020) $
+# $Revision: 12420 $
+
+import operator
+import functools
 
 from drip import models
 from drip import utils
