@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11769 2019-10-29 11:39:50Z Andy $
+# $Id: models.py 12486 2020-08-27 11:15:48Z Casey $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Andy $
-# $Date: 2019-10-29 19:39:50 +0800 (Tue, 29 Oct 2019) $
-# $Revision: 11769 $
+# $Author: Casey $
+# $Date: 2020-08-27 19:15:48 +0800 (Thu, 27 Aug 2020) $
+# $Revision: 12486 $
 
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
@@ -34,6 +34,10 @@ class AdminPlaceholder(models.Model):
         
     def __unicode__(self):
         return u"AdminPlaceholder: %d" % (self.id,)
+
+    class Meta:
+        verbose_name = _('AdminPlaceholder')
+        verbose_name_plural = _('AdminPlaceholderr')
         
         
 class BlockDisplayControl(models.Model):
@@ -52,3 +56,7 @@ class BlockDisplayControl(models.Model):
         
     def __unicode__(self):
         return u"BlockDisplayControl: %d" % (self.id,)
+
+    class Meta:
+        verbose_name = _('BlockDisplayControl')
+        verbose_name_plural = _('BlockDisplayControl')
